==> qmltube_0.2.18.tar.gz: qmltube-0.2.18/main.cpp <==
#include "qmlapplicationviewer.h"
#include "controller.h"
#include "youtube.h"
#include "downloadmanager.h"
#include <QtGui/QApplication>
#include <QDeclarativeContext>
#include <QtDeclarative>

#ifdef Q_WS_MAEMO_5
#include <QtOpenGL/QGLWidget>
#endif

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
    app.setApplicationName("FMRadio");

    QmlApplicationViewer viewer;

    QDeclarativeContext *context = viewer.rootContext();
    Controller ct;
    ct.setView(&viewer);
    YouTube yt;
    DownloadManager dm;
    QNetworkAccessManager *manager = new QNetworkAccessManager();
    yt.setNetworkAccessManager(manager);
    dm.setNetworkAccessManager(manager);
    context->setContextProperty("Controller", &ct);
    context->setContextProperty("DownloadManager", &dm);
    context->setContextProperty("YouTube", &yt);

#ifdef Q_WS_MAEMO_5
    viewer.engine()->addImportPath(QString("/opt/qtm11/imports"));
    viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
    QDir path;
    path.setPath("/home/user/.config/cutetube");
    if (!path.exists()) {
        path.mkpath("/home/user/.config/cutetube");
    }
    path.setPath("/home/user/MyDocs/.cutetube");
    if (!path.exists()) {
        path.mkpath("/home/user/MyDocs/.cutetube");
    }
    viewer.setViewport(new QGLWidget());
#endif

    viewer.setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
    viewer.setMainQmlFile(QLatin1String("qml/qmltube/main.qml"));
    viewer.showFullScreen();

    return app.exec();
}

==> qmltube_0.2.20.tar.gz: qmltube-0.2.20/main.cpp <==
#include "qmlapplicationviewer.h"
#include "controller.h"
#include "youtube.h"
#include "downloadmanager.h"
#include <QtGui/QApplication>
#include <QDeclarativeContext>
#include <QtDeclarative>

#ifdef Q_WS_MAEMO_5
#include <QtOpenGL/QGLWidget>
#endif

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
    app.setApplicationName("FMRadio");

    QmlApplicationViewer viewer;

    QDeclarativeContext *context = viewer.rootContext();
    Controller ct;
    ct.setView(&viewer);
    YouTube yt;
    DownloadManager dm;
    QNetworkAccessManager *manager = new QNetworkAccessManager();
    yt.setNetworkAccessManager(manager);
    dm.setNetworkAccessManager(manager);
    context->setContextProperty("Controller", &ct);
    context->setContextProperty("DownloadManager", &dm);
    context->setContextProperty("YouTube", &yt);

#ifdef Q_WS_MAEMO_5
//    viewer.engine()->addImportPath(QString("/opt/qtm11/imports"));
    viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
    QDir path;
    path.setPath("/home/user/.config/cutetube");
    if (!path.exists()) {
        path.mkpath("/home/user/.config/cutetube");
    }
    path.setPath("/home/user/MyDocs/.cutetube");
    if (!path.exists()) {
        path.mkpath("/home/user/MyDocs/.cutetube");
    }
    viewer.setViewport(new QGLWidget());
#endif

    viewer.setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
    viewer.setMainQmlFile(QLatin1String("qml/qmltube/main.qml"));
    viewer.showFullScreen();

    return app.exec();
}
